@@ -30,7 +30,6 @@
 #define HAVE_DLFCN_H 1
 #define HAVE_EXECINFO_H 1
 #define HAVE_FCNTL_H 1
-#define HAVE_FCNTL_DIRECT 1
 #define HAVE_FENV_H 1
 #define HAVE_FLOAT_H 1
 #define HAVE_FNMATCH_H 1
@@ -152,7 +151,6 @@
 #define HAVE_GETCWD 1
 #define HAVE_GETHOSTBYADDR_R 1
 /* #undef HAVE_GETHRTIME */
-#define HAVE_GETPAGESIZE 1
 /* #undef HAVE_GETPAGESIZES */
 #define HAVE_GETPASS 1
 /* #undef HAVE_GETPASSPHRASE */
@@ -185,6 +183,7 @@
 #define HAVE_MLOCKALL 1
 #define HAVE_MMAP 1
 #define HAVE_MMAP64 1
+#define HAVE_MPROTECT 1
 #define HAVE_PERROR 1
 #define HAVE_POLL 1
 #define HAVE_POSIX_FALLOCATE 1
@@ -403,38 +402,27 @@
 #define SIGNAL_WITH_VIO_CLOSE 1
 
 /* Windows stuff, mostly functions, that have Posix analogs but named differently */
-/* #undef S_IROTH */
-/* #undef S_IFIFO */
-/* #undef IPPROTO_IPV6 */
-/* #undef IPV6_V6ONLY */
-/* #undef sigset_t */
-/* #undef mode_t */
-/* #undef SIGQUIT */
-/* #undef SIGPIPE */
-/* #undef popen */
-/* #undef pclose */
-/* #undef ssize_t */
-/* #undef strcasecmp */
-/* #undef strncasecmp */
-/* #undef snprintf */
-/* #undef strtok_r */
-/* #undef strtoll */
-/* #undef strtoull */
-/* #undef vsnprintf */
-#if defined(_MSC_VER) && (_MSC_VER > 1800)
+#ifdef _WIN32
+#define S_IROTH _S_IREAD
+#define S_IFIFO _S_IFIFO
+#define SIGQUIT SIGTERM
+#define SIGPIPE SIGINT
+#define sigset_t int
+#define mode_t int
+#define popen _popen
+#define pclose _pclose
+#define ssize_t SSIZE_T
+#define strcasecmp _stricmp
+#define strncasecmp _strnicmp
+#define strtok_r strtok_s
 #define tzname _tzname
 #define P_tmpdir "C:\\TEMP"
-#endif
-#if defined(_MSC_VER) && (_MSC_VER > 1310)
-# define HAVE_SETENV
 #define setenv(a,b,c) _putenv_s(a,b)
-#endif
-#define PSAPI_VERSION 1     /* for GetProcessMemoryInfo() */
 
-/* We don't want the min/max macros */
-#ifdef _WIN32
+#define HAVE_SETENV
 #define NOMINMAX 1
-#endif
+#define PSAPI_VERSION 2     /* for GetProcessMemoryInfo() */
+#endif /* _WIN32 */
 
 /*
   MySQL features
@@ -458,6 +446,11 @@
 /* This should mean case insensitive file system */
 /* #undef FN_NO_CASE_SENSE */
 
+/* Whether an anonymous private mapping is unaccessible after
+madvise(MADV_DONTNEED) or madvise(MADV_FREE) or similar has been invoked;
+this is the case with Microsoft Windows VirtualFree(MEM_DECOMMIT) */
+/* #undef HAVE_UNACCESSIBLE_AFTER_MEM_DECOMMIT */
+
 #define HAVE_CHARSET_armscii8 1
 #define HAVE_CHARSET_ascii 1
 #define HAVE_CHARSET_big5 1
@@ -532,17 +525,17 @@
 /* #undef SO_EXT */
 
 #define MYSQL_VERSION_MAJOR 10
-#define MYSQL_VERSION_MINOR 6
-#define MYSQL_VERSION_PATCH 25
+#define MYSQL_VERSION_MINOR 11
+#define MYSQL_VERSION_PATCH 13
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.6.25"
+#define PACKAGE_STRING "MySQL Server 10.11.13"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.6.25"
-#define VERSION "10.6.25"
+#define PACKAGE_VERSION "10.11.13"
+#define VERSION "10.11.13"
 #define PROTOCOL_VERSION 10
 #define PCRE2_CODE_UNIT_WIDTH 8
 
